import { Slot, DefineComponent, VNode, RendererNode, RendererElement, ComponentOptionsMixin, VNodeProps, AllowedComponentProps, ComponentCustomProps, App } from 'vue';

declare type Name = string | symbol;
interface TransportInput {
    to: Name;
    from: Name;
    order?: number;
    content: Slot;
}
declare type TransportsHub = Map<Name, TransportsByTarget>;
declare type TransportsByTarget = Map<Name, Transport>;
interface Transport {
    to: Name;
    from: Name;
    order: number;
    content: Slot;
}
interface TransportCloser {
    to: Name;
    from?: Name;
}
declare type PortalTargetProps = Partial<{
    multiple: boolean;
    name: Name;
    slotProps: object;
}>;
declare type Wormhole = Readonly<{
    open: (t: TransportInput) => void;
    close: (t: TransportCloser) => void;
    getContentForTarget: (t: Name, returnAll?: boolean) => Transport[];
    transports: TransportsHub;
}>;

declare const _default: DefineComponent<{
    disabled: {
        type: BooleanConstructor;
    };
    name: {
        type: (SymbolConstructor | StringConstructor)[];
        default: () => symbol;
    };
    order: {
        type: NumberConstructor;
    };
    slotProps: {
        type: ObjectConstructor;
        default: () => {};
    };
    to: {
        type: StringConstructor;
        default: () => string;
    };
}, () => VNode<RendererNode, RendererElement, {
    [key: string]: any;
}>[] | null, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    to: string;
    name: Name;
    disabled: boolean;
    slotProps: Record<string, any>;
} & {
    order?: number | undefined;
}>, {
    to: string;
    name: Name;
    disabled: boolean;
    slotProps: Record<string, any>;
}>;

declare const _default$1: DefineComponent<{
    multiple: {
        type: BooleanConstructor;
        default: boolean;
    };
    name: {
        type: StringConstructor;
        required: true;
    };
    slotProps: {
        type: ObjectConstructor;
        default: () => {};
    };
}, () => VNode<RendererNode, RendererElement, {
    [key: string]: any;
}>[] | undefined, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, "change"[], "change", VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    multiple: boolean;
    name: string;
    slotProps: Record<string, any>;
} & {}>, {
    multiple: boolean;
    slotProps: Record<string, any>;
}>;

declare function useWormhole(): Readonly<{
    open: (t: TransportInput) => void;
    close: (t: TransportCloser) => void;
    getContentForTarget: (t: Name, returnAll?: boolean | undefined) => Transport[];
    transports: TransportsHub;
}>;
declare function provideWormhole(wormhole: Wormhole): void;

declare function createWormhole(asReadonly?: boolean): Wormhole;

declare function mountPortalTarget(targetProps: PortalTargetProps, el: HTMLElement | string): void;

interface PluginOptions {
    portalName?: string | false;
    portalTargetName?: string | false;
    MountingPortalName?: string;
    wormhole?: Wormhole;
}
declare function install(app: App, options?: PluginOptions): void;
declare const Wormhole$1: Readonly<{
    open: (t: TransportInput) => void;
    close: (t: TransportCloser) => void;
    getContentForTarget: (t: string | symbol, returnAll?: boolean | undefined) => Transport[];
    transports: TransportsHub;
}>;
declare const version: string;

export default install;
export { PluginOptions, _default as Portal, _default$1 as PortalTarget, Wormhole as TWormhole, Wormhole$1 as Wormhole, createWormhole, install, mountPortalTarget, provideWormhole, useWormhole, version };
